@@ -4,7 +4,7 @@ These files are reported as candidates for removal.
 
 """
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 
 import argparse
@@ -38,7 +38,7 @@ def grep(text, path, exclude):
                                      '--recursive',
                                      '--binary-files=without-match'] +
                                     ['--exclude=' + x
-                                     for x in [text] + exclude] +
+                                     for x in exclude] +
                                     [text,
                                      os.path.join(root, name)]):
                 return True
@@ -66,7 +66,9 @@ def unreferenced_files(path, exclude_referrers):
     Completely ignore hidden directories when recursing directories.
 
     """
-    _grep = lambda x: grep(x, path, exclude=exclude_referrers)
+    _grep = lambda x: grep(x,
+                           path,
+                           exclude=exclude_referrers + [os.path.join(path, x)])
 
     for root, directories, filenames in os.walk(path):
         for name in filenames:
